#!/bin/bash

 STEPS=90

 OUTPUTDIR=o
 TMPDIR=tmp
 PDFLIST=$TMPDIR/pdfs.list
 TMPTEX=grafik2slits.tex

# ------------------------------------------------- #
  find i/pdf/words/_Nimbus_Sans_L_ -name "*.pdf" | \
  shuf -n 2 > $PDFLIST
# ------------------------------------------------- #

 PDF=`find i/pdf -name "*.pdf" | shuf -n 1`
 PDF="i/pdf/var/A4_referenzblatt.pdf"

 IDENTIFY=`identify $PDF`
 PDFWIDTH=`echo $IDENTIFY | \
           cut -d " " -f 3 | \
           head -1 | cut -d "x" -f 1`
 PDFHEIGHT=`echo $IDENTIFY | \
            cut -d " " -f 3 | \
            head -1 | cut -d "x" -f 2`

 STEPWIDTH=`expr $PDFWIDTH \/ $STEPS`

 VERTICALOFFSET=`expr $STEPS + \`expr $STEPS \/ 4 \``


  echo "\documentclass[9pt]{scrbook}                  " >  $TMPTEX
  echo "\usepackage{pdfpages}                         " >> $TMPTEX
  echo "\usepackage{geometry}                         " >> $TMPTEX
  echo "\geometry{paperwidth=595pt,paperheight=842pt} " >> $TMPTEX

  echo "\usepackage[pdftex]{epsfig}                   " >> $TMPTEX

  echo "\setlength{\unitlength}{"$STEPWIDTH"pt}       " >> $TMPTEX
  echo "\setlength\topmargin{-0.1in}                  " >> $TMPTEX
  echo "\setlength\oddsidemargin{-1.2in}              " >> $TMPTEX
  echo "\setlength\textwidth{\paperwidth}             " >> $TMPTEX

  echo "\newcommand{                                  " >> $TMPTEX
  echo "\graphic}[6]{                                 " >> $TMPTEX
  echo "\includegraphics[viewport=#2 #3 #4 #5,clip,   " >> $TMPTEX
  echo "height=\paperheight]{#1}}                     " >> $TMPTEX

  echo "\begin{document}                              " >> $TMPTEX
  echo "                                              " >> $TMPTEX


  # ------------------------------------------------------- #
    echo "\\begin{picture}(0,0)                " >> $TMPTEX

    CNT=0
    while [ $CNT -lt $STEPS ]
     do
        LEFT=`expr $CNT \* $STEPWIDTH`
        RIGHT=`expr $STEPWIDTH + $LEFT`

        PDF=`cat $PDFLIST | shuf -n 1`

        echo  "\put("$CNT",-"$VERTICALOFFSET"){" >> $TMPTEX
        echo  "\graphic{"$PDF"}{"$LEFT"}{0}    " >> $TMPTEX
        echo  "{"$RIGHT"}{"$PDFHEIGHT"}}       " >> $TMPTEX

        CNT=`expr $CNT + 1`
    done

   echo "\end{picture}                         " >> $TMPTEX
  # ------------------------------------------------------- #

 echo "\end{document}                                " >> $TMPTEX

 pdflatex -output-directory $OUTPUTDIR $TMPTEX

 rm $TMPTEX

exit 0;


